fill_and_smooth

Function fill_and_smooth 

fn fill_and_smooth(
    lowpass: &mut [f64],
    stable_mean: f64,
    sigma2: [f64; 3],
    nx: usize,
    ny: usize,
    nz: usize,
)
Fill holes and smooth the lowpass field with weighted smoothing

Matches MriResearchTools.jl’s fillandsmooth! function. Uses weighted smoothing where filled holes get weight 0.2.